pub enum BacktestError {
EmptyEvents,
InvalidEventLimit,
InvalidCaptureRate,
EventLimitExceeded {
actual: usize,
maximum: usize,
},
InvalidInitialValue(f64),
NonMonotonicTimestamp {
index: usize,
previous: i64,
current: i64,
},
Decision {
index: usize,
message: String,
},
Transition {
index: usize,
action_index: usize,
message: String,
},
NonFiniteValue {
index: usize,
value: f64,
},
InvalidProjection(String),
Cancelled,
DeadlineExceeded,
}Expand description
Failure while validating input or replaying.
Variants
EmptyEvents
Backtest requires at least one historical event.
InvalidEventLimit
Max_events must be greater than 0.
InvalidCaptureRate
Capture_every must be greater than 0.
EventLimitExceeded
More events than max_events.
InvalidInitialValue(f64)
Initial value must be finite and greater than zero, got.
NonMonotonicTimestamp
Event timestamps are out of order at index index: previous > current.
Fields
Decision
The model failed to decide on an event.
Transition
State transition failed at event index, action action_index: message.
Fields
NonFiniteValue
The model produced NaN or infinity.
InvalidProjection(String)
Invalid projection policy.
Cancelled
Replay observed cancellation between events.
DeadlineExceeded
Replay exceeded its caller-provided deadline.